========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/oslo.service.svg
    :target: https://governance.openstack.org/tc/ference/tags/index.html

.. Change things from this point on

========================================================
 oslo.service -- Library for running OpenStack services
========================================================

.. image:: https://img.shields.io/pypi/v/oslo.service.svg
    :target: https://pypi.org/project/oslo.service/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/oslo.service.svg
    :target: https://pypi.org/project/oslo.service/
    :alt: Downloads

oslo.service provides a framework for defining new long-running
services using the patterns established by other OpenStack
applications. It also includes utilities long-running applications
might need for working with SSL or WSGI, performing periodic
operations, interacting with systemd, etc.

* Free software: Apache license
* Documentation: https://docs.openstack.org/oslo.service/latest/
* Source: https://opendev.org/openstack/oslo.service
* Bugs: https://bugs.launchpad.net/oslo.service
* Release notes: https://docs.openstack.org/releasenotes/oslo.service/
